==> open-xchange-core_7.10.5.orig.tar.bz2: open-xchange-core-7.10.5/com.openexchange.health.rest/src/com/openexchange/health/rest/osgi/MWHealthCheckRestActivator.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.health.rest.osgi;

import com.openexchange.config.lean.LeanConfigurationService;
import com.openexchange.health.MWHealthCheckService;
import com.openexchange.health.rest.MWHealthCheckRestEndpoint;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.version.VersionService;

/**
 * {@link MWHealthCheckRestActivator}
 *
 * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
 * @since v7.10.1
 */
public class MWHealthCheckRestActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { MWHealthCheckService.class, LeanConfigurationService.class, VersionService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        registerService(MWHealthCheckRestEndpoint.class, new MWHealthCheckRestEndpoint(this));
    }

}

==> open-xchange-core_7.10.6.orig.tar.bz2: open-xchange-core-7.10.6/com.openexchange.health.rest/src/com/openexchange/health/rest/osgi/MWHealthCheckRestActivator.java <==
/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.health.rest.osgi;

import com.openexchange.config.lean.LeanConfigurationService;
import com.openexchange.health.MWHealthCheckService;
import com.openexchange.health.rest.MWHealthCheckReadynessEndpoint;
import com.openexchange.health.rest.MWHealthCheckRestEndpoint;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.version.VersionService;

/**
 * {@link MWHealthCheckRestActivator}
 *
 * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
 * @since v7.10.1
 */
public class MWHealthCheckRestActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { MWHealthCheckService.class, LeanConfigurationService.class, VersionService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        registerService(MWHealthCheckRestEndpoint.class, new MWHealthCheckRestEndpoint(this));
        registerService(MWHealthCheckReadynessEndpoint.class, new MWHealthCheckReadynessEndpoint(this));
    }

}
